==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-networkmonitor/translations/networkmonitor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="159"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Interfejs sieci &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="160"/>
        <source>Transmitted %1</source>
        <translation>Przesłano %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Received %1</source>
        <translation>Otrzymano %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="206"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor settings</source>
        <translation>Ustawienia monitora sieci</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="56"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="65"/>
        <source>Monitor</source>
        <translation>Monitor</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="74"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="83"/>
        <source>Wireless</source>
        <translation>Bezprzewodowe</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="95"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-networkmonitor/translations/networkmonitor_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtNetworkMonitor</name>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="159"/>
        <source>Network interface &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Interfejs sieci &lt;b&gt;%1&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="160"/>
        <source>Transmitted %1</source>
        <translation>Przesłano %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="161"/>
        <source>Received %1</source>
        <translation>Otrzymano %1</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="206"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitor.cpp" line="207"/>
        <source>PiB</source>
        <translation>PiB</translation>
    </message>
</context>
<context>
    <name>LXQtNetworkMonitorConfiguration</name>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="14"/>
        <source>Network Monitor Settings</source>
        <translation>Ustawienia monitora sieci</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="82"/>
        <source>Interface</source>
        <translation>Interfejs</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="43"/>
        <source>Modem</source>
        <translation>Modem</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="52"/>
        <source>Monitor</source>
        <translation>Monitor</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="61"/>
        <source>Network</source>
        <translation>Sieć</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="70"/>
        <source>Wireless</source>
        <translation>Bezprzewodowe</translation>
    </message>
    <message>
        <location filename="../lxqtnetworkmonitorconfiguration.ui" line="35"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
</context>
</TS>
